<?php
/**
 * Donut Theme Customizer support
 *
 * @package Donut
 */

/** 
 * Donut customizer 
*/
function donut_customize_register( $wp_customize ) {
	// Add postMessage support for site title and description.
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'            => '.site-title a',
				'container_inclusive' => false,
				'render_callback'     => 'donut_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'            => '.site-description',
				'container_inclusive' => false,
				'render_callback'     => 'donut_customize_partial_blogdescription',
			)
		);
	}

	// Rename the label to "Site Title Color" because this only affects the site title in this theme.
	$wp_customize->get_control( 'header_textcolor' )->label = __( 'Site Title Color', 'donut' );

	// Rename the label to "Display Site Title & Tagline" in order to make this option extra clear.
	$wp_customize->get_control( 'display_header_text' )->label = __( 'Display Site Title &amp; Tagline', 'donut' );

	// Add custom description to Colors and Background controls or sections.
	if ( property_exists( $wp_customize->get_control( 'background_color' ), 'description' ) ) {
		$wp_customize->get_control( 'background_color' )->description = __( 'May only be visible on wide screens.', 'donut' );
		$wp_customize->get_control( 'background_image' )->description = __( 'May only be visible on wide screens.', 'donut' );
	} else {
		$wp_customize->get_section( 'colors' )->description           = __( 'Background may only be visible on wide screens.', 'donut' );
		$wp_customize->get_section( 'background_image' )->description = __( 'Background may only be visible on wide screens.', 'donut' );
	}
}
add_action( 'customize_register', 'donut_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @since Donut 1.7
 * @see donut_customize_register()
 *
 * @return void
 */
function donut_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @since Donut 1.7
 * @see donut_customize_register()
 *
 * @return void
 */
function donut_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Bind JS handlers to make Customizer preview reload changes asynchronously.
 *
 * @since Donut 1.0
 */
function donut_customize_preview_js() {
	wp_enqueue_script( 'donut_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20131205', true );
}
add_action( 'customize_preview_init', 'donut_customize_preview_js' );

/**
 * Add contextual help to the Themes and Post edit screens.
 *
 * @since Donut 1.0
 */
function donut_contextual_help() {
	if ( 'admin_head-edit.php' === current_filter() && 'post' !== $GLOBALS['typenow'] ) {
		return;
	}

	get_current_screen()->add_help_tab(
		array(
			'id'      => 'donut',
			'title'   => __( 'donut', 'donut' ),
			'content' =>
				'<ul>' .
					'<li>' . /* translators: %1$s,%2$s,%3$s: term */sprintf( __( 'The home page features your choice of up to 6 posts prominently displayed in a grid or slider, controlled by a <a href="%1$s">tag</a>; you can change the tag and layout in <a href="%2$s">Appearance &rarr; Customize</a>. If no posts match the tag, <a href="%3$s">sticky posts</a> will be displayed instead.', 'donut' ), esc_url( add_query_arg( 'tag', _x( 'featured', 'featured content default tag slug', 'donut' ), admin_url( 'edit.php' ) ) ), admin_url( 'customize.php' ), admin_url( 'edit.php?show_sticky=1' ) ) . '</li>' .
					'<li>' . sprintf( __( 'Enhance your site design by using <a href="%s">Featured Images</a> for posts you&rsquo;d like to stand out (also known as post thumbnails). This allows you to associate an image with your post without inserting it. donut uses featured images for posts and pages&mdash;above the title&mdash;and in the Featured Content area on the home page.', 'donut' ), 'http://codex.wordpress.org/Post_Thumbnails#Setting_a_Post_Thumbnail' ) . '</li>' .
					'<li>' . /* translators: %s: search term */sprintf( __( 'For an in-depth tutorial, and more tips and tricks, visit the <a href="%s">donut documentation</a>.', 'donut' ), 'http://codex.wordpress.org' ) . '</li>' .
				'</ul>',
		)
	);
}
add_action( 'admin_head-themes.php', 'donut_contextual_help' );
add_action( 'admin_head-edit.php', 'donut_contextual_help' );
